@@ -173,7 +173,7 @@ class LoLMatch:
         subbed = await cls.get_sub_tournament(group_id)
         print(subbed)
         if subbed:
-            return "已订阅赛事ID: " + " ".join(str(x["tournament"]) for x in subbed)
+            return "已订阅赛事ID: " + " ".join(str(x.tournament) for x in subbed)
         else:
             return "没有订阅"
 
